diff -r 82814a8a2395 bismark_methylation_extractor.py
--- a/bismark_methylation_extractor.py	Wed Aug 21 05:19:54 2013 -0400
+++ b/bismark_methylation_extractor.py	Tue Apr 08 01:26:27 2014 -0400
@@ -27,7 +27,7 @@
     # input options
     parser.add_argument( '--bismark_path', dest='bismark_path', help='Path to the bismark perl scripts' )
 
-    parser.add_argument( '--infile', help='Input file in SAM format.' )
+    parser.add_argument( '--infile', help='Input file in SAM or BAM format.' )
     parser.add_argument( '--single-end', dest='single_end', action="store_true" )
     parser.add_argument( '--paired-end', dest='paired_end', action="store_true" )
 
@@ -93,9 +93,15 @@
     if args.report_file:
         additional_opts += ' --report '
 
-
-    # Final command:
-    cmd = cmd % (output_dir, additional_opts, args.infile)
+    #detect BAM file, use samtools view if it is a bam file
+    f = open (args.infile, 'rb')
+    sig = f.read(4)
+    f.close()
+    if sig == '\x1f\x8b\x08\x04' :
+	cmd = cmd % (output_dir, additional_opts, '-')	
+	cmd = 'samtools view %s | %s' % (args.infile, cmd )
+    else :
+        cmd = cmd % (output_dir, additional_opts, args.infile)
 
     # Run
     try:
diff -r 82814a8a2395 bismark_methylation_extractor.xml
--- a/bismark_methylation_extractor.xml	Wed Aug 21 05:19:54 2013 -0400
+++ b/bismark_methylation_extractor.xml	Tue Apr 08 01:26:27 2014 -0400
@@ -1,6 +1,6 @@
-<tool id="bismark_methylation_extractor" name="Bismark" version="0.7.12">
+<tool id="bismark_methylation_extractor" name="Bismark Extractor" version="0.7.12">
     <!-- Wrapper compatible with Bismark version 0.7.7 -->
-    <description>methylation extractor</description>
+    <description>Bismark methylation extractor</description>
     <!--<version_command>bismark_methylation_extractor version</version_command>-->
     <requirements>
         <requirement type="set_environment">SCRIPT_PATH</requirement>
@@ -81,7 +81,7 @@
     </command>
     <inputs>
         <!-- Input Parameters -->
-        <param name="input" type="data" format="sam" label="SAM file from Bismark bisulfid mapper" />
+        <param name="input" type="data" format="sam,bam" label="SAM/BAM file from Bismark bisulfite mapper" />
         <conditional name="singlePaired">
             <param name="sPaired" type="select" label="Is this library mate-paired?">
               <option value="single">Single-end</option>
diff -r 82814a8a2395 bismark_wrapper.py
--- a/bismark_wrapper.py	Wed Aug 21 05:19:54 2013 -0400
+++ b/bismark_wrapper.py	Tue Apr 08 01:26:27 2014 -0400
@@ -176,10 +176,10 @@
     #tmp_bismark_dir = tempfile.mkdtemp( dir='/data/0/galaxy_db/tmp/' )
     tmp_bismark_dir = tempfile.mkdtemp()
     output_dir = os.path.join( tmp_bismark_dir, 'results')
-    cmd = 'bismark %(args)s --bam --temp_dir %(tmp_bismark_dir)s -o %(output_dir)s --quiet %(genome_folder)s %(reads)s'
+    cmd = 'bismark %(args)s --bam --temp_dir %(tmp_bismark_dir)s --gzip -o %(output_dir)s --quiet %(genome_folder)s %(reads)s'
 
     if args.fasta:
-        # he query input files (specified as mate1,mate2 or singles) are FastA
+        # the query input files (specified as mate1,mate2 or singles) are FastA
         cmd = '%s %s' % (cmd, '--fasta')
     elif args.fastq:
         cmd = '%s %s' % (cmd, '--fastq')
@@ -327,20 +327,19 @@
 
         bam_files = glob( os.path.join( output_dir, '*.bam') )
         if len( bam_files ) > 1:
-            cmd = 'samtools merge -@ %s -f - %s ' % ( args.num_threads, ' '.join( bam_files ) )
+            cmd = 'samtools merge -@ %s -f %s %s ' % ( args.num_threads, tmp_res, ' '.join( bam_files ) )
 
-            p1 = subprocess.Popen( args=shlex.split( cmd ), stdout=subprocess.PIPE )
-            proc = subprocess.Popen( ['samtools', 'sort', '-@', str(args.num_threads), '-', tmp_res], stdin=p1.stdout, stdout=tmp_stdout, stderr=tmp_stderr )
+            proc = subprocess.Popen( args=shlex.split( cmd ), stdout=subprocess.PIPE )
+
+            returncode = proc.wait()
+            tmp_stdout.close()
+            tmp_stderr.close()
+            if returncode != 0:
+                raise Exception, open( tmp_stderr.name ).read()
         else:
-            proc = subprocess.Popen( ['samtools', 'sort', '-@', str(args.num_threads), bam_files[0], tmp_res], stdout=tmp_stdout, stderr=tmp_stderr )
+	    tmp_res = bam_files[0]
 
-        returncode = proc.wait()
-        tmp_stdout.close()
-        tmp_stderr.close()
-        if returncode != 0:
-            raise Exception, open( tmp_stderr.name ).read()
-
-        bam_path = "%s.bam" % tmp_res
+        bam_path = "%s" % tmp_res
         if os.path.exists( bam_path ):
             shutil.copy( bam_path, args.output )
         else:
